<?php

use App\Http\Middleware\IsAdmin;
use App\Http\Middleware\PreventRequestsDuringMaintenance;
use App\Http\Middleware\TrimStrings;
use Illuminate\Foundation\Application;
use Illuminate\Foundation\Configuration\Exceptions;
use Illuminate\Foundation\Configuration\Middleware;
use Illuminate\Foundation\Http\Middleware\ConvertEmptyStringsToNull;
use Illuminate\Foundation\Http\Middleware\ValidatePostSize;

return Application::configure(basePath: dirname(__DIR__))
    ->withRouting(
        web: __DIR__.'/../routes/web.php',
        commands: __DIR__.'/../routes/console.php',
        health: '/up',
    )
    ->withMiddleware(function (Middleware $middleware) {


        // ------- Global Middleware ------- //

        $middleware->append([
            PreventRequestsDuringMaintenance::class,
            ValidatePostSize::class,
            TrimStrings::class,
            ConvertEmptyStringsToNull::class,

        ]);
        // --------------------------------- //
       
        
        // ------ Admin Middleware ------ //
        $middleware->alias([
            // Admin Middleware
            'admin' => IsAdmin::class,
            // Vendor Middleware
            'vendor' => \App\Http\Middleware\Vendor::class,
            // Vendor Verified Middleware
            'is_vendor_verified' => \App\Http\Middleware\Vendor::class,
        ]);


     
    })
    ->withExceptions(function (Exceptions $exceptions) {
        //
    })->create();
